/* FILE: functions.h                    -*-Mode: c++-*-
 *
 * Non-class C++ functions defined by the Nb extension.
 * 
 * NOTICE: Please see the file ../../LICENSE
 *
 * Last modified on: $Date: 2003/11/20 22:41:30 $
 * Last modified by: $Author: dgp $
 */

#ifndef _NB_FUNCTIONS
#define _NB_FUNCTIONS

#include "dstring.h"

/* End includes */     /* Optional directive to build.tcl */

// Greatest Common Divisor
int Nb_Gcd(int m,int n);
Tcl_CmdProc NbGcdCmd;

// Sign function
inline int Nb_Signum(double x) { return (x>0 ? 1 : (x<0 ? -1 : 0)); }

// Simple continued fraction like rational approximator
void Nb_RatApprox(double x,int steps,int &num,int &denom);
Tcl_CmdProc NbRatApprox;

// Version of atof that allows 'D' or 'd' to be used to denote exponent.
double Nb_Atof(const char *nptr);

// Version of strtod that allows 'D' or 'd' to be used to denote exponent
double Nb_Strtod(const char *nptr,char **endptr);

// Version of Nb_Atof with error checking.  Export value 'error'
// is set true if an error occurred, false otherwise.
double Nb_Atof(const char *nptr,BOOL& error);

// Atan2 inverse, in where import "angle" is specified in degrees
void degcossin(double angle,double& cosine,double& sine);

// Routines to detect IEEE floating point NAN's and infinities.
int Nb_IsFinite(REAL4 x);
int Nb_IsFinite(REAL8 x);

// Routine to detect string containing nothing but whitespace.
int Nb_StrIsSpace(const char* str);

// Portable case insensitive string comparison, modeled after
// BSD's strcasecmp().
int Nb_StrCaseCmp(const char *s1, const char *s2);

// Portable thread-safe string tokenizer, modeled after BSD's strsep().
// Compare also to strtok().
char* Nb_StrSep(char **stringp, const char *delim);

// Map color strings to real [0,1] rgb values.
// Returns 1 on success, 0 on error.
BOOL Nb_GetColor(const char* color,
		 REAL8m& red,REAL8m& green,REAL8m& blue);
Tcl_CmdProc NbGetColor;

// C interface to the Tcl 'file nativename' functionality.
void Nb_TclNativeFilename(Nb_DString &filename);

// A version of fopen that calls Nb_TclNativeFilename().
FILE *Nb_FOpen(const char *path,const char *mode);

// A version of remove that calls Nb_TclNativeFilename().
int Nb_Remove(const char *path);

// Interfaces to Tcl_Write.  The first in intended mainly
// as an interface layer in case we decide in the future to
// use Tcl_WriteObj in place of Tcl_Write.  If bytecount
// is <0, then buf should be NULL terminated, and everything
// up to the NULL byte is output.  The return value is the
// number of bytes written, or -1 in case of error.
INT4m Nb_WriteChannel(Tcl_Channel channel,const char* buf,INT4m bytecount);
UINT4m Nb_FprintfChannel(Tcl_Channel channel,char* buf,UINT4m bufsize,
			 const char* format, ...);
/// Nb_FprintfChannel requires a workspace buffer 'buf' to store
/// the formatted string passed on to Tcl_Write.  The size of this
/// buffer in specified in bytecount.  If the formatted string is
/// bigger than bytecount, a panic occurs inside Oc_Vsnprintf (which
/// is called by this function).  For convenience, the client may
/// specify NULL for buf, in which case internal storage is used.
/// But bytecount must still be appropriately specified.


//////////////////////////////////////////////////////////////////////////
// Routines to interchange two values
template<class T> void Nb_Swap(T &x,T &y);  // Explicit, separate declaration
/// to help HP CC auto-instantiation.

// Include definition in header to aid GCC's auto-instantiation.
template<class T> void Nb_Swap(T &x,T &y) {
  T temp=x; x=y; y=temp;
}

#endif /* _NB_FUNCTIONS */
