/* FILE: autobuf.cc                   -*-Mode: c++-*-
 *
 * NOTICE: Please see the file ../../LICENSE
 *
 * Last modified on: $Date: 2003/11/20 22:41:32 $
 * Last modified by: $Author: dgp $
 */

/* Standard libraries */
#include <string.h>

/* Other classes and functions in this extension */
#include "autobuf.h"
#include "imports.h"

/* End includes */     

const size_t Oc_AutoBuf::reclaim_bound=1024;   // See Oc_AutoBuf::Dup()
const size_t Oc_AutoBuf::reclaim_proportion=4;

void Oc_AutoBuf::Dup(const char* const_str)
{
  size_t needsize=strlen(const_str)+1;
  if(needsize>bufsize || 
     (bufsize>reclaim_bound && bufsize/reclaim_proportion>needsize)) {
    if(bufsize>0) delete[] str;
    bufsize=needsize;
    str=new char[bufsize];
    if(str==0) panic((char *)"No memory in Oc_AutoBuf::Dup");
  }
  strcpy(str,const_str);
}
 
Oc_AutoBuf::Oc_AutoBuf()
{
  bufsize=0;
  str=NULL; // Safety
  Dup("");
}
 
Oc_AutoBuf::Oc_AutoBuf(const char* const_str)
{
  bufsize=0;
  str=NULL; // Safety
  Dup(const_str);
}
 
char* Oc_AutoBuf::operator()(const char* const_str)
{
  Dup(const_str);
  return str;
}
 
Oc_AutoBuf::~Oc_AutoBuf()
{
  delete[] str;
}

